@@ -1,10 +1,11 @@
 from .unitok import UniTok
-from UniTok.vocab.vocab import Vocab
-from UniTok.vocab.depot import VocabDepot
+from .vocab import Vocab
+from .vocab.depot import VocabDepot
 from .column import Column
 from .analysis import LengthAnalysis, Plot
 from .unidep import UniDep
 from .classify import Classify
+from .global_setting import Global
 
 __all__ = [
     UniTok,
@@ -17,4 +18,5 @@ __all__ = [
     Vocab,
     VocabDepot,
     Classify,
+    Global,
 ]
